@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
  * Copyright (C) 2007 Jimmy Gilles <jimmygilles@gmail.com>
- * Copyright (C) 2008,2009,2010,2011,2012,2013 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ * Copyright (C) 2008,2009,2010,2011,2012,2013,2014 Rolf Eike Beer <kde@opensource.sf-tec.de>
  * Copyright (C) 2011 Philip Greggory Lee <rocketman768@gmail.com>
  */
 
@@ -28,6 +28,7 @@
 
 #include <KComboBox>
 #include <KDatePicker>
+#include <KGlobal>
 #include <KLocale>
 #include <KMessageBox>
 #include <KPushButton>
@@ -201,11 +202,11 @@ void KgpgKeyInfo::displayKey()
     m_id->setText(m_node->getId().right(16));
     m_algorithm->setText(Convert::toString(key->algorithm()) + QLatin1String( " / " ) + Convert::toString(key->encryptionAlgorithm()));
     m_algorithm->setWhatsThis(i18n("<qt>The left part is the algorithm used by the <b>signature</b> key. The right part is the algorithm used by the <b>encryption</b> key.</qt>"));
-    m_creation->setText(Convert::toString(m_node->getCreation().date()));
+    m_creation->setText(KGlobal::locale()->formatDate(m_node->getCreation().date(), KLocale::ShortDate));
     if (m_node->getExpiration().isNull())
         m_expiration->setText(i18nc("Unlimited key lifetime", "Unlimited"));
     else
-        m_expiration->setText(Convert::toString(m_node->getExpiration().date()));
+        m_expiration->setText(KGlobal::locale()->formatDate(m_node->getExpiration().date(), KLocale::ShortDate));
     m_trust->setText(trust);
     m_trust->setColor(trustcolor);
     m_length->setText(m_node->getSize());
@@ -223,23 +224,23 @@ void KgpgKeyInfo::displayKey()
 
     switch (key->ownerTrust())
     {
-        case OWTRUST_NONE:
+        case GPGME_VALIDITY_NEVER:
             m_owtrust->setCurrentIndex(1);
             break;
 
-        case OWTRUST_MARGINAL:
+        case GPGME_VALIDITY_MARGINAL:
             m_owtrust->setCurrentIndex(2);
             break;
 
-        case OWTRUST_FULL:
+        case GPGME_VALIDITY_FULL:
             m_owtrust->setCurrentIndex(3);
             break;
 
-        case OWTRUST_ULTIMATE:
+        case GPGME_VALIDITY_ULTIMATE:
             m_owtrust->setCurrentIndex(4);
             break;
 
-        case OWTRUST_UNDEFINED:
+        case GPGME_VALIDITY_UNDEFINED:
         default:
             m_owtrust->setCurrentIndex(0);
             break;
@@ -277,7 +278,7 @@ void KgpgKeyInfo::slotChangeDate()
 	delete dialog;
 }
 
-void KgpgKeyInfo::slotDisableKey(const bool &ison)
+void KgpgKeyInfo::slotDisableKey(const bool ison)
 {
 	keychange->setDisable(ison);
 	enableButtonApply(keychange->wasChanged());
@@ -313,13 +314,13 @@ void KgpgKeyInfo::slotInfoPasswordChanged(int result)
 	}
 }
 
-void KgpgKeyInfo::slotChangeTrust(const int &newtrust)
+void KgpgKeyInfo::slotChangeTrust(const int newtrust)
 {
-	keychange->setOwTrust(KgpgKeyOwnerTrust(newtrust + 1));
+	keychange->setOwTrust(static_cast<gpgme_validity_t>(newtrust + 1));
 	enableButtonApply(keychange->wasChanged());
 }
 
-void KgpgKeyInfo::setControlEnable(const bool &b)
+void KgpgKeyInfo::setControlEnable(const bool b)
 {
     m_owtrust->setEnabled(b);
     m_disable->setEnabled(b);
