@@ -26,7 +26,7 @@ class KGpgChangeDisable: public KGpgEditKeyTransaction {
 
 	Q_DISABLE_COPY(KGpgChangeDisable)
 public:
-	KGpgChangeDisable(QObject *parent, const QString &keyid, const bool &disable);
+	KGpgChangeDisable(QObject *parent, const QString &keyid, const bool disable);
 	virtual ~KGpgChangeDisable();
 
 	void setDisable(bool disable);
